"""This module contains the general information for AdaptorFcIfEventStats ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class AdaptorFcIfEventStatsConsts():
    INVALID_CRCCOUNT_NA = "NA"
    INVALID_CRCCOUNT_DELTA_NA = "NA"
    INVALID_CRCCOUNT_DELTA_AVG_NA = "NA"
    INVALID_CRCCOUNT_DELTA_MAX_NA = "NA"
    INVALID_CRCCOUNT_DELTA_MIN_NA = "NA"
    LINK_FAILURE_COUNT_NA = "NA"
    LINK_FAILURE_COUNT_DELTA_NA = "NA"
    LINK_FAILURE_COUNT_DELTA_AVG_NA = "NA"
    LINK_FAILURE_COUNT_DELTA_MAX_NA = "NA"
    LINK_FAILURE_COUNT_DELTA_MIN_NA = "NA"
    LIP_COUNT_NA = "NA"
    LIP_COUNT_DELTA_NA = "NA"
    LIP_COUNT_DELTA_AVG_NA = "NA"
    LIP_COUNT_DELTA_MAX_NA = "NA"
    LIP_COUNT_DELTA_MIN_NA = "NA"
    LOSS_OF_SIGNAL_COUNT_NA = "NA"
    LOSS_OF_SIGNAL_COUNT_DELTA_NA = "NA"
    LOSS_OF_SIGNAL_COUNT_DELTA_AVG_NA = "NA"
    LOSS_OF_SIGNAL_COUNT_DELTA_MAX_NA = "NA"
    LOSS_OF_SIGNAL_COUNT_DELTA_MIN_NA = "NA"
    LOSS_OF_SYNC_COUNT_NA = "NA"
    LOSS_OF_SYNC_COUNT_DELTA_NA = "NA"
    LOSS_OF_SYNC_COUNT_DELTA_AVG_NA = "NA"
    LOSS_OF_SYNC_COUNT_DELTA_MAX_NA = "NA"
    LOSS_OF_SYNC_COUNT_DELTA_MIN_NA = "NA"
    N_OSCOUNT_NA = "NA"
    N_OSCOUNT_DELTA_NA = "NA"
    N_OSCOUNT_DELTA_AVG_NA = "NA"
    N_OSCOUNT_DELTA_MAX_NA = "NA"
    N_OSCOUNT_DELTA_MIN_NA = "NA"
    SECONDS_SINCE_LAST_RESET_NA = "NA"
    SECONDS_SINCE_LAST_RESET_DELTA_NA = "NA"
    SECONDS_SINCE_LAST_RESET_DELTA_AVG_NA = "NA"
    SECONDS_SINCE_LAST_RESET_DELTA_MAX_NA = "NA"
    SECONDS_SINCE_LAST_RESET_DELTA_MIN_NA = "NA"
    SEQ_PROTOCOL_ERR_COUNT_NA = "NA"
    SEQ_PROTOCOL_ERR_COUNT_DELTA_NA = "NA"
    SEQ_PROTOCOL_ERR_COUNT_DELTA_AVG_NA = "NA"
    SEQ_PROTOCOL_ERR_COUNT_DELTA_MAX_NA = "NA"
    SEQ_PROTOCOL_ERR_COUNT_DELTA_MIN_NA = "NA"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class AdaptorFcIfEventStats(ManagedObject):
    """This is AdaptorFcIfEventStats class."""

    consts = AdaptorFcIfEventStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("AdaptorFcIfEventStats", "adaptorFcIfEventStats", "fc-if-event-stats", VersionMeta.Version111a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], [u'adaptorHostFcIf'], [u'adaptorFcIfEventStatsHist'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "invalid_crc_count": MoPropertyMeta("invalid_crc_count", "invalidCRCCount", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "invalid_crc_count_delta": MoPropertyMeta("invalid_crc_count_delta", "invalidCRCCountDelta", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "invalid_crc_count_delta_avg": MoPropertyMeta("invalid_crc_count_delta_avg", "invalidCRCCountDeltaAvg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "invalid_crc_count_delta_max": MoPropertyMeta("invalid_crc_count_delta_max", "invalidCRCCountDeltaMax", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "invalid_crc_count_delta_min": MoPropertyMeta("invalid_crc_count_delta_min", "invalidCRCCountDeltaMin", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "link_failure_count": MoPropertyMeta("link_failure_count", "linkFailureCount", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "link_failure_count_delta": MoPropertyMeta("link_failure_count_delta", "linkFailureCountDelta", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "link_failure_count_delta_avg": MoPropertyMeta("link_failure_count_delta_avg", "linkFailureCountDeltaAvg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "link_failure_count_delta_max": MoPropertyMeta("link_failure_count_delta_max", "linkFailureCountDeltaMax", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "link_failure_count_delta_min": MoPropertyMeta("link_failure_count_delta_min", "linkFailureCountDeltaMin", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "lip_count": MoPropertyMeta("lip_count", "lipCount", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "lip_count_delta": MoPropertyMeta("lip_count_delta", "lipCountDelta", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "lip_count_delta_avg": MoPropertyMeta("lip_count_delta_avg", "lipCountDeltaAvg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "lip_count_delta_max": MoPropertyMeta("lip_count_delta_max", "lipCountDeltaMax", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "lip_count_delta_min": MoPropertyMeta("lip_count_delta_min", "lipCountDeltaMin", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "loss_of_signal_count": MoPropertyMeta("loss_of_signal_count", "lossOfSignalCount", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "loss_of_signal_count_delta": MoPropertyMeta("loss_of_signal_count_delta", "lossOfSignalCountDelta", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "loss_of_signal_count_delta_avg": MoPropertyMeta("loss_of_signal_count_delta_avg", "lossOfSignalCountDeltaAvg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "loss_of_signal_count_delta_max": MoPropertyMeta("loss_of_signal_count_delta_max", "lossOfSignalCountDeltaMax", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "loss_of_signal_count_delta_min": MoPropertyMeta("loss_of_signal_count_delta_min", "lossOfSignalCountDeltaMin", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "loss_of_sync_count": MoPropertyMeta("loss_of_sync_count", "lossOfSyncCount", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "loss_of_sync_count_delta": MoPropertyMeta("loss_of_sync_count_delta", "lossOfSyncCountDelta", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "loss_of_sync_count_delta_avg": MoPropertyMeta("loss_of_sync_count_delta_avg", "lossOfSyncCountDeltaAvg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "loss_of_sync_count_delta_max": MoPropertyMeta("loss_of_sync_count_delta_max", "lossOfSyncCountDeltaMax", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "loss_of_sync_count_delta_min": MoPropertyMeta("loss_of_sync_count_delta_min", "lossOfSyncCountDeltaMin", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "n_os_count": MoPropertyMeta("n_os_count", "nOSCount", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "n_os_count_delta": MoPropertyMeta("n_os_count_delta", "nOSCountDelta", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "n_os_count_delta_avg": MoPropertyMeta("n_os_count_delta_avg", "nOSCountDeltaAvg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "n_os_count_delta_max": MoPropertyMeta("n_os_count_delta_max", "nOSCountDeltaMax", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "n_os_count_delta_min": MoPropertyMeta("n_os_count_delta_min", "nOSCountDeltaMin", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "normalized_time_col": MoPropertyMeta("normalized_time_col", "normalizedTimeCol", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "seconds_since_last_reset": MoPropertyMeta("seconds_since_last_reset", "secondsSinceLastReset", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "seconds_since_last_reset_delta": MoPropertyMeta("seconds_since_last_reset_delta", "secondsSinceLastResetDelta", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "seconds_since_last_reset_delta_avg": MoPropertyMeta("seconds_since_last_reset_delta_avg", "secondsSinceLastResetDeltaAvg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "seconds_since_last_reset_delta_max": MoPropertyMeta("seconds_since_last_reset_delta_max", "secondsSinceLastResetDeltaMax", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "seconds_since_last_reset_delta_min": MoPropertyMeta("seconds_since_last_reset_delta_min", "secondsSinceLastResetDeltaMin", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "seq_protocol_err_count": MoPropertyMeta("seq_protocol_err_count", "seqProtocolErrCount", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "seq_protocol_err_count_delta": MoPropertyMeta("seq_protocol_err_count_delta", "seqProtocolErrCountDelta", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "seq_protocol_err_count_delta_avg": MoPropertyMeta("seq_protocol_err_count_delta_avg", "seqProtocolErrCountDeltaAvg", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "seq_protocol_err_count_delta_max": MoPropertyMeta("seq_protocol_err_count_delta_max", "seqProtocolErrCountDeltaMax", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "seq_protocol_err_count_delta_min": MoPropertyMeta("seq_protocol_err_count_delta_min", "seqProtocolErrCountDeltaMin", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["NA"], ["0-4294967295"]), 
        "stats_reported": MoPropertyMeta("stats_reported", "statsReported", "int", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "invalidCRCCount": "invalid_crc_count", 
        "invalidCRCCountDelta": "invalid_crc_count_delta", 
        "invalidCRCCountDeltaAvg": "invalid_crc_count_delta_avg", 
        "invalidCRCCountDeltaMax": "invalid_crc_count_delta_max", 
        "invalidCRCCountDeltaMin": "invalid_crc_count_delta_min", 
        "linkFailureCount": "link_failure_count", 
        "linkFailureCountDelta": "link_failure_count_delta", 
        "linkFailureCountDeltaAvg": "link_failure_count_delta_avg", 
        "linkFailureCountDeltaMax": "link_failure_count_delta_max", 
        "linkFailureCountDeltaMin": "link_failure_count_delta_min", 
        "lipCount": "lip_count", 
        "lipCountDelta": "lip_count_delta", 
        "lipCountDeltaAvg": "lip_count_delta_avg", 
        "lipCountDeltaMax": "lip_count_delta_max", 
        "lipCountDeltaMin": "lip_count_delta_min", 
        "lossOfSignalCount": "loss_of_signal_count", 
        "lossOfSignalCountDelta": "loss_of_signal_count_delta", 
        "lossOfSignalCountDeltaAvg": "loss_of_signal_count_delta_avg", 
        "lossOfSignalCountDeltaMax": "loss_of_signal_count_delta_max", 
        "lossOfSignalCountDeltaMin": "loss_of_signal_count_delta_min", 
        "lossOfSyncCount": "loss_of_sync_count", 
        "lossOfSyncCountDelta": "loss_of_sync_count_delta", 
        "lossOfSyncCountDeltaAvg": "loss_of_sync_count_delta_avg", 
        "lossOfSyncCountDeltaMax": "loss_of_sync_count_delta_max", 
        "lossOfSyncCountDeltaMin": "loss_of_sync_count_delta_min", 
        "nOSCount": "n_os_count", 
        "nOSCountDelta": "n_os_count_delta", 
        "nOSCountDeltaAvg": "n_os_count_delta_avg", 
        "nOSCountDeltaMax": "n_os_count_delta_max", 
        "nOSCountDeltaMin": "n_os_count_delta_min", 
        "normalizedTimeCol": "normalized_time_col", 
        "rn": "rn", 
        "secondsSinceLastReset": "seconds_since_last_reset", 
        "secondsSinceLastResetDelta": "seconds_since_last_reset_delta", 
        "secondsSinceLastResetDeltaAvg": "seconds_since_last_reset_delta_avg", 
        "secondsSinceLastResetDeltaMax": "seconds_since_last_reset_delta_max", 
        "secondsSinceLastResetDeltaMin": "seconds_since_last_reset_delta_min", 
        "seqProtocolErrCount": "seq_protocol_err_count", 
        "seqProtocolErrCountDelta": "seq_protocol_err_count_delta", 
        "seqProtocolErrCountDeltaAvg": "seq_protocol_err_count_delta_avg", 
        "seqProtocolErrCountDeltaMax": "seq_protocol_err_count_delta_max", 
        "seqProtocolErrCountDeltaMin": "seq_protocol_err_count_delta_min", 
        "statsReported": "stats_reported", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.intervals = None
        self.invalid_crc_count = None
        self.invalid_crc_count_delta = None
        self.invalid_crc_count_delta_avg = None
        self.invalid_crc_count_delta_max = None
        self.invalid_crc_count_delta_min = None
        self.link_failure_count = None
        self.link_failure_count_delta = None
        self.link_failure_count_delta_avg = None
        self.link_failure_count_delta_max = None
        self.link_failure_count_delta_min = None
        self.lip_count = None
        self.lip_count_delta = None
        self.lip_count_delta_avg = None
        self.lip_count_delta_max = None
        self.lip_count_delta_min = None
        self.loss_of_signal_count = None
        self.loss_of_signal_count_delta = None
        self.loss_of_signal_count_delta_avg = None
        self.loss_of_signal_count_delta_max = None
        self.loss_of_signal_count_delta_min = None
        self.loss_of_sync_count = None
        self.loss_of_sync_count_delta = None
        self.loss_of_sync_count_delta_avg = None
        self.loss_of_sync_count_delta_max = None
        self.loss_of_sync_count_delta_min = None
        self.n_os_count = None
        self.n_os_count_delta = None
        self.n_os_count_delta_avg = None
        self.n_os_count_delta_max = None
        self.n_os_count_delta_min = None
        self.normalized_time_col = None
        self.seconds_since_last_reset = None
        self.seconds_since_last_reset_delta = None
        self.seconds_since_last_reset_delta_avg = None
        self.seconds_since_last_reset_delta_max = None
        self.seconds_since_last_reset_delta_min = None
        self.seq_protocol_err_count = None
        self.seq_protocol_err_count_delta = None
        self.seq_protocol_err_count_delta_avg = None
        self.seq_protocol_err_count_delta_max = None
        self.seq_protocol_err_count_delta_min = None
        self.stats_reported = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "AdaptorFcIfEventStats", parent_mo_or_dn, **kwargs)




"""This module contains the general information for StorageFcTargetEp ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StorageFcTargetEpConsts():
    PATH_A = "A"
    PATH_B = "B"
    PATH_NONE = "NONE"
    PATH_DUAL = "dual"
    PATH_MGMT = "mgmt"


class StorageFcTargetEp(ManagedObject):
    """This is StorageFcTargetEp class."""

    consts = StorageFcTargetEpConsts()
    naming_props = set([u'targetwwpn'])

    mo_meta = MoMeta("StorageFcTargetEp", "storageFcTargetEp", "fc-target-ep-[targetwwpn]", VersionMeta.Version111a, "InputOutput", 0x7f, [], ["admin", "ext-san-config", "ext-san-policy", "ls-storage", "ls-storage-policy"], [u'storageConnectionDef', u'storageConnectionPolicy'], [u'storageVsanRef'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x2, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "path": MoPropertyMeta("path", "path", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["A", "B", "NONE", "dual", "mgmt"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "targetwwpn": MoPropertyMeta("targetwwpn", "targetwwpn", "string", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x40, 0, 256, r"""(([A-Fa-f0-9][A-Fa-f0-9]:){7}[A-Fa-f0-9][A-Fa-f0-9])|0""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "path": "path", 
        "rn": "rn", 
        "status": "status", 
        "targetwwpn": "targetwwpn", 
    }

    def __init__(self, parent_mo_or_dn, targetwwpn, **kwargs):
        self._dirty_mask = 0
        self.targetwwpn = targetwwpn
        self.child_action = None
        self.descr = None
        self.path = None
        self.status = None

        ManagedObject.__init__(self, "StorageFcTargetEp", parent_mo_or_dn, **kwargs)




"""This module contains the general information for VnicLstorageIScsi ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class VnicLstorageIScsiConsts():
    ADDR_DERIVED = "derived"
    ADMIN_HOST_PORT_1 = "1"
    ADMIN_HOST_PORT_2 = "2"
    ADMIN_HOST_PORT_ANY = "ANY"
    ADMIN_HOST_PORT_NONE = "NONE"
    ADMIN_VCON_1 = "1"
    ADMIN_VCON_2 = "2"
    ADMIN_VCON_3 = "3"
    ADMIN_VCON_4 = "4"
    ADMIN_VCON_ANY = "any"
    CDN_SOURCE_USER_DEFINED = "user-defined"
    CDN_SOURCE_VNIC_NAME = "vnic-name"
    CONFIG_STATE_APPLIED = "applied"
    CONFIG_STATE_APPLYING = "applying"
    CONFIG_STATE_FAILED_TO_APPLY = "failed-to-apply"
    CONFIG_STATE_NOT_APPLIED = "not-applied"
    INST_TYPE_DEFAULT = "default"
    INST_TYPE_DYNAMIC = "dynamic"
    INST_TYPE_DYNAMIC_VF = "dynamic-vf"
    INST_TYPE_MANUAL = "manual"
    OPER_HOST_PORT_1 = "1"
    OPER_HOST_PORT_2 = "2"
    OPER_HOST_PORT_ANY = "ANY"
    OPER_HOST_PORT_NONE = "NONE"
    OPER_ORDER_UNSPECIFIED = "unspecified"
    OPER_SPEED_LINE_RATE = "line-rate"
    OPER_VCON_1 = "1"
    OPER_VCON_2 = "2"
    OPER_VCON_3 = "3"
    OPER_VCON_4 = "4"
    OPER_VCON_ANY = "any"
    ORDER_UNSPECIFIED = "unspecified"
    OWNER_CONN_POLICY = "conn_policy"
    OWNER_INITIATOR_POLICY = "initiator_policy"
    OWNER_LOGICAL = "logical"
    OWNER_PHYSICAL = "physical"
    OWNER_POLICY = "policy"
    OWNER_UNKNOWN = "unknown"
    REDUNDANCY_PAIR_TYPE_NONE = "none"
    REDUNDANCY_PAIR_TYPE_PRIMARY = "primary"
    REDUNDANCY_PAIR_TYPE_SECONDARY = "secondary"
    SWITCH_ID_A = "A"
    SWITCH_ID_AB = "AB"
    SWITCH_ID_B = "B"
    SWITCH_ID_NONE = "NONE"
    SWITCH_ID_MGMT = "mgmt"
    TYPE_ETHER = "ether"
    TYPE_FC = "fc"
    TYPE_IPC = "ipc"
    TYPE_SCSI = "scsi"
    TYPE_UNKNOWN = "unknown"


class VnicLstorageIScsi(ManagedObject):
    """This is VnicLstorageIScsi class."""

    consts = VnicLstorageIScsiConsts()
    naming_props = set([u'name'])

    mo_meta = MoMeta("VnicLstorageIScsi", "vnicLstorageIScsi", "lstorageIScsi-[name]", VersionMeta.Version131a, "InputOutput", 0xfffff, [], ["admin", "ls-config", "ls-network", "ls-server", "ls-storage"], [u'lsServer'], [u'fabricEthMonSrcEp', u'fabricFcMonSrcEp', u'faultInst', u'vnicVlan'], ["Get"])

    prop_meta = {
        "adaptor_profile_name": MoPropertyMeta("adaptor_profile_name", "adaptorProfileName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x2, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "addr": MoPropertyMeta("addr", "addr", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""(([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F]))|0""", ["derived"], []), 
        "admin_cdn_name": MoPropertyMeta("admin_cdn_name", "adminCdnName", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "admin_host_port": MoPropertyMeta("admin_host_port", "adminHostPort", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["1", "2", "ANY", "NONE"], []), 
        "admin_vcon": MoPropertyMeta("admin_vcon", "adminVcon", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["1", "2", "3", "4", "any"], []), 
        "boot_dev": MoPropertyMeta("boot_dev", "bootDev", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "cdn_source": MoPropertyMeta("cdn_source", "cdnSource", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["user-defined", "vnic-name"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "config_qualifier": MoPropertyMeta("config_qualifier", "configQualifier", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|not-applicable|adaptor-protected-eth-capability|vif-resources-overprovisioned|ungrouped-domain|unsupported-nvgre|unsupported-adaptor-for-vnic-cdn|misconfigured-net-san-group|unresolved-remote-vlan-name|invalid-wwn|service-profile-virtualization-conflict|unsupported-roce-netflow|unsupported-vxlan-netflow|redundancy-vnicpair-not-in-sync|fcoe-capacity|wwpn-derivation-virtualized-port|unresolved-vlan-name|vnic-virtualization-netflow-conflict|unsupported-vxlan-usnic|unsupported-roce-properties|pinning-vlan-mismatch|adaptor-requirement|vnic-not-ha-ready|missing-ipv4-inband-mgmt-addr|unsupported-nvgre-dynamic-vnic|duplicate-vnic-cdn-name|overlapping-vlans|unresolved-remote-vsan-name|mac-derivation-virtualized-port|vnic-virtualization-conflict|unsupported-roce|unsupported-nvgre-netflow|unsupported-adaptor-for-vnic-oracle-rac|vnic-vlan-assignment-error|insufficient-vhba-capacity|inaccessible-vlan|unable-to-update-ucsm|soft-pinning-vlan-mismatch|unsupported-roce-sriov|unsupported-geneve-usnic-vmq|unsupported-nvgre-vmq|connection-placement|vnic-vcon-provisioning-change|missing-ipv6-inband-mgmt-addr|unsupported-nvgre-usnic|insufficient-roce-resources|missing-primary-vlan|adaptor-fcoe-capability|vfc-vnic-pvlan-conflict|virtualization-not-supported|unsupported-vxlan|unsupported-roce-nvgre|unresolved-net-san-group|unresolved-vsan-name|insufficient-vnic-capacity|unassociated-vlan|unsupported-roce-vmq|unsupported-roce-vxlan|unsupported-vxlan-vmq|redundancy-vnic-not-in-pair|dynamic-vf-vnic|wwpn-assignment|missing-ipv4-addr|unsupported-vxlan-dynamic-vnic|pinned-target-misconfig|unsupported-vmq-resources),){0,65}(defaultValue|not-applicable|adaptor-protected-eth-capability|vif-resources-overprovisioned|ungrouped-domain|unsupported-nvgre|unsupported-adaptor-for-vnic-cdn|misconfigured-net-san-group|unresolved-remote-vlan-name|invalid-wwn|service-profile-virtualization-conflict|unsupported-roce-netflow|unsupported-vxlan-netflow|redundancy-vnicpair-not-in-sync|fcoe-capacity|wwpn-derivation-virtualized-port|unresolved-vlan-name|vnic-virtualization-netflow-conflict|unsupported-vxlan-usnic|unsupported-roce-properties|pinning-vlan-mismatch|adaptor-requirement|vnic-not-ha-ready|missing-ipv4-inband-mgmt-addr|unsupported-nvgre-dynamic-vnic|duplicate-vnic-cdn-name|overlapping-vlans|unresolved-remote-vsan-name|mac-derivation-virtualized-port|vnic-virtualization-conflict|unsupported-roce|unsupported-nvgre-netflow|unsupported-adaptor-for-vnic-oracle-rac|vnic-vlan-assignment-error|insufficient-vhba-capacity|inaccessible-vlan|unable-to-update-ucsm|soft-pinning-vlan-mismatch|unsupported-roce-sriov|unsupported-geneve-usnic-vmq|unsupported-nvgre-vmq|connection-placement|vnic-vcon-provisioning-change|missing-ipv6-inband-mgmt-addr|unsupported-nvgre-usnic|insufficient-roce-resources|missing-primary-vlan|adaptor-fcoe-capability|vfc-vnic-pvlan-conflict|virtualization-not-supported|unsupported-vxlan|unsupported-roce-nvgre|unresolved-net-san-group|unresolved-vsan-name|insufficient-vnic-capacity|unassociated-vlan|unsupported-roce-vmq|unsupported-roce-vxlan|unsupported-vxlan-vmq|redundancy-vnic-not-in-pair|dynamic-vf-vnic|wwpn-assignment|missing-ipv4-addr|unsupported-vxlan-dynamic-vnic|pinned-target-misconfig|unsupported-vmq-resources){0,1}""", [], []), 
        "config_state": MoPropertyMeta("config_state", "configState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["applied", "applying", "failed-to-apply", "not-applied"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []), 
        "equipment_dn": MoPropertyMeta("equipment_dn", "equipmentDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "flt_aggr": MoPropertyMeta("flt_aggr", "fltAggr", "ulong", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, None, [], []), 
        "ident_pool_name": MoPropertyMeta("ident_pool_name", "identPoolName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, [], []), 
        "inst_type": MoPropertyMeta("inst_type", "instType", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["default", "dynamic", "dynamic-vf", "manual"], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version131a, MoPropertyMeta.NAMING, 0x200, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []), 
        "nw_templ_name": MoPropertyMeta("nw_templ_name", "nwTemplName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x400, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "oper_adaptor_profile_name": MoPropertyMeta("oper_adaptor_profile_name", "operAdaptorProfileName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "oper_cdn_name": MoPropertyMeta("oper_cdn_name", "operCdnName", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "oper_host_port": MoPropertyMeta("oper_host_port", "operHostPort", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["1", "2", "ANY", "NONE"], []), 
        "oper_ident_pool_name": MoPropertyMeta("oper_ident_pool_name", "operIdentPoolName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "oper_order": MoPropertyMeta("oper_order", "operOrder", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "oper_speed": MoPropertyMeta("oper_speed", "operSpeed", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["line-rate"], ["8-40000000"]), 
        "oper_stats_policy_name": MoPropertyMeta("oper_stats_policy_name", "operStatsPolicyName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "oper_vcon": MoPropertyMeta("oper_vcon", "operVcon", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["1", "2", "3", "4", "any"], []), 
        "order": MoPropertyMeta("order", "order", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x800, None, None, None, ["unspecified"], ["0-256"]), 
        "owner": MoPropertyMeta("owner", "owner", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["conn_policy", "initiator_policy", "logical", "physical", "policy", "unknown"], []), 
        "pin_to_group_name": MoPropertyMeta("pin_to_group_name", "pinToGroupName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x1000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "qos_policy_name": MoPropertyMeta("qos_policy_name", "qosPolicyName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x2000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "redundancy_pair_type": MoPropertyMeta("redundancy_pair_type", "redundancyPairType", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["none", "primary", "secondary"], []), 
        "redundancy_peer": MoPropertyMeta("redundancy_peer", "redundancyPeer", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x4000, 0, 256, None, [], []), 
        "role": MoPropertyMeta("role", "role", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x8000, None, None, r"""((defaultValue|none|nfs|node-mgmt|node-ha-state|cifs|data-protection|iscsi),){0,7}(defaultValue|none|nfs|node-mgmt|node-ha-state|cifs|data-protection|iscsi){0,1}""", [], []), 
        "stats_policy_name": MoPropertyMeta("stats_policy_name", "statsPolicyName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x20000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "switch_id": MoPropertyMeta("switch_id", "switchId", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x40000, None, None, None, ["A", "AB", "B", "NONE", "mgmt"], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["ether", "fc", "ipc", "scsi", "unknown"], []), 
        "vnic_name": MoPropertyMeta("vnic_name", "vnicName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x80000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
    }

    prop_map = {
        "adaptorProfileName": "adaptor_profile_name", 
        "addr": "addr", 
        "adminCdnName": "admin_cdn_name", 
        "adminHostPort": "admin_host_port", 
        "adminVcon": "admin_vcon", 
        "bootDev": "boot_dev", 
        "cdnSource": "cdn_source", 
        "childAction": "child_action", 
        "configQualifier": "config_qualifier", 
        "configState": "config_state", 
        "dn": "dn", 
        "equipmentDn": "equipment_dn", 
        "fltAggr": "flt_aggr", 
        "identPoolName": "ident_pool_name", 
        "instType": "inst_type", 
        "name": "name", 
        "nwTemplName": "nw_templ_name", 
        "operAdaptorProfileName": "oper_adaptor_profile_name", 
        "operCdnName": "oper_cdn_name", 
        "operHostPort": "oper_host_port", 
        "operIdentPoolName": "oper_ident_pool_name", 
        "operOrder": "oper_order", 
        "operSpeed": "oper_speed", 
        "operStatsPolicyName": "oper_stats_policy_name", 
        "operVcon": "oper_vcon", 
        "order": "order", 
        "owner": "owner", 
        "pinToGroupName": "pin_to_group_name", 
        "qosPolicyName": "qos_policy_name", 
        "redundancyPairType": "redundancy_pair_type", 
        "redundancyPeer": "redundancy_peer", 
        "rn": "rn", 
        "role": "role", 
        "statsPolicyName": "stats_policy_name", 
        "status": "status", 
        "switchId": "switch_id", 
        "type": "type", 
        "vnicName": "vnic_name", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.adaptor_profile_name = None
        self.addr = None
        self.admin_cdn_name = None
        self.admin_host_port = None
        self.admin_vcon = None
        self.boot_dev = None
        self.cdn_source = None
        self.child_action = None
        self.config_qualifier = None
        self.config_state = None
        self.equipment_dn = None
        self.flt_aggr = None
        self.ident_pool_name = None
        self.inst_type = None
        self.nw_templ_name = None
        self.oper_adaptor_profile_name = None
        self.oper_cdn_name = None
        self.oper_host_port = None
        self.oper_ident_pool_name = None
        self.oper_order = None
        self.oper_speed = None
        self.oper_stats_policy_name = None
        self.oper_vcon = None
        self.order = None
        self.owner = None
        self.pin_to_group_name = None
        self.qos_policy_name = None
        self.redundancy_pair_type = None
        self.redundancy_peer = None
        self.role = None
        self.stats_policy_name = None
        self.status = None
        self.switch_id = None
        self.type = None
        self.vnic_name = None

        ManagedObject.__init__(self, "VnicLstorageIScsi", parent_mo_or_dn, **kwargs)




"""This module contains the general information for StatsThrFloatValue ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StatsThrFloatValueConsts():
    DIRECTION_ABOVE_NORMAL = "aboveNormal"
    DIRECTION_BELOW_NORMAL = "belowNormal"
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    POLICY_OWNER_UNSPECIFIED = "unspecified"
    PROP_TYPE_FLOAT = "float"
    PROP_TYPE_UINT32 = "uint32"
    PROP_TYPE_UINT64 = "uint64"
    SEVERITY_CLEARED = "cleared"
    SEVERITY_CONDITION = "condition"
    SEVERITY_CRITICAL = "critical"
    SEVERITY_INFO = "info"
    SEVERITY_MAJOR = "major"
    SEVERITY_MINOR = "minor"
    SEVERITY_WARNING = "warning"


class StatsThrFloatValue(ManagedObject):
    """This is StatsThrFloatValue class."""

    consts = StatsThrFloatValueConsts()
    naming_props = set([u'direction', u'severity'])

    mo_meta = MoMeta("StatsThrFloatValue", "statsThrFloatValue", "[direction]-[severity]", VersionMeta.Version101a, "InputOutput", 0x3ff, [], ["admin", "operations"], [u'statsThr32Definition', u'statsThr64Definition', u'statsThrFloatDefinition'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "deescalating": MoPropertyMeta("deescalating", "deescalating", "float", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "direction": MoPropertyMeta("direction", "direction", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x8, None, None, None, ["aboveNormal", "belowNormal"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "escalating": MoPropertyMeta("escalating", "escalating", "float", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], []), 
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["local", "pending-policy", "policy", "unspecified"], []), 
        "prop_type": MoPropertyMeta("prop_type", "propType", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["float", "uint32", "uint64"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []), 
        "severity": MoPropertyMeta("severity", "severity", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x100, None, None, None, ["cleared", "condition", "critical", "info", "major", "minor", "warning"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "deescalating": "deescalating", 
        "descr": "descr", 
        "direction": "direction", 
        "dn": "dn", 
        "escalating": "escalating", 
        "intId": "int_id", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "propType": "prop_type", 
        "rn": "rn", 
        "severity": "severity", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, direction, severity, **kwargs):
        self._dirty_mask = 0
        self.direction = direction
        self.severity = severity
        self.child_action = None
        self.deescalating = None
        self.descr = None
        self.escalating = None
        self.int_id = None
        self.name = None
        self.policy_level = None
        self.policy_owner = None
        self.prop_type = None
        self.status = None

        ManagedObject.__init__(self, "StatsThrFloatValue", parent_mo_or_dn, **kwargs)




"""This module contains the meta information of FabricPermitsForExistingVlanNames ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("FabricPermitsForExistingVlanNames", "fabricPermitsForExistingVlanNames", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_org_dn": MethodPropertyMeta("InOrgDn", "inOrgDn", "ReferenceObject", "Version142b", "Input", False),
    "out_vlan_permits": MethodPropertyMeta("OutVlanPermits", "outVlanPermits", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "inOrgDn": "in_org_dn",
    "outVlanPermits": "out_vlan_permits",
}




"""This module contains the meta information of OrgGetDomainFirmwareReport ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("OrgGetDomainFirmwareReport", "orgGetDomainFirmwareReport", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_domain_group_dn": MethodPropertyMeta("InDomainGroupDn", "inDomainGroupDn", "ReferenceObject", "Version142b", "Input", False),
    "in_domain_list": MethodPropertyMeta("InDomainList", "inDomainList", "ConfigSet", "Version142b", "Input", True),
    "in_firmware_type": MethodPropertyMeta("InFirmwareType", "inFirmwareType", "Xs:string", "Version142b", "Input", False),
    "in_maint_tag": MethodPropertyMeta("InMaintTag", "inMaintTag", "Xs:string", "Version142b", "Input", False),
    "out_firmware_oper_state": MethodPropertyMeta("OutFirmwareOperState", "outFirmwareOperState", "Xs:string", "Version142b", "Output", False),
    "out_firmware_report_set": MethodPropertyMeta("OutFirmwareReportSet", "outFirmwareReportSet", "ConfigSet", "Version142b", "Output", True),
    "out_firmware_version_set": MethodPropertyMeta("OutFirmwareVersionSet", "outFirmwareVersionSet", "DnSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "inDomainGroupDn": "in_domain_group_dn",
    "inDomainList": "in_domain_list",
    "inFirmwareType": "in_firmware_type",
    "inMaintTag": "in_maint_tag",
    "outFirmwareOperState": "out_firmware_oper_state",
    "outFirmwareReportSet": "out_firmware_report_set",
    "outFirmwareVersionSet": "out_firmware_version_set",
}




"""This module contains the general information for ProcessorErrorStats ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ProcessorErrorStatsConsts():
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class ProcessorErrorStats(ManagedObject):
    """This is ProcessorErrorStats class."""

    consts = ProcessorErrorStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ProcessorErrorStats", "processorErrorStats", "error-stats", VersionMeta.Version111a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], [u'processorUnit'], [u'processorErrorStatsHist'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "mirroring_inter_sock_errors": MoPropertyMeta("mirroring_inter_sock_errors", "mirroringInterSockErrors", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "mirroring_inter_sock_errors_avg": MoPropertyMeta("mirroring_inter_sock_errors_avg", "mirroringInterSockErrorsAvg", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "mirroring_inter_sock_errors_max": MoPropertyMeta("mirroring_inter_sock_errors_max", "mirroringInterSockErrorsMax", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "mirroring_inter_sock_errors_min": MoPropertyMeta("mirroring_inter_sock_errors_min", "mirroringInterSockErrorsMin", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "mirroring_inter_sock_errors_running": MoPropertyMeta("mirroring_inter_sock_errors_running", "mirroringInterSockErrorsRunning", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "mirroring_intra_sock_errors": MoPropertyMeta("mirroring_intra_sock_errors", "mirroringIntraSockErrors", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "mirroring_intra_sock_errors_avg": MoPropertyMeta("mirroring_intra_sock_errors_avg", "mirroringIntraSockErrorsAvg", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "mirroring_intra_sock_errors_max": MoPropertyMeta("mirroring_intra_sock_errors_max", "mirroringIntraSockErrorsMax", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "mirroring_intra_sock_errors_min": MoPropertyMeta("mirroring_intra_sock_errors_min", "mirroringIntraSockErrorsMin", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "mirroring_intra_sock_errors_running": MoPropertyMeta("mirroring_intra_sock_errors_running", "mirroringIntraSockErrorsRunning", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "normalized_time_col": MoPropertyMeta("normalized_time_col", "normalizedTimeCol", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "smi_link_corr_errors": MoPropertyMeta("smi_link_corr_errors", "smiLinkCorrErrors", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "smi_link_corr_errors_avg": MoPropertyMeta("smi_link_corr_errors_avg", "smiLinkCorrErrorsAvg", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "smi_link_corr_errors_max": MoPropertyMeta("smi_link_corr_errors_max", "smiLinkCorrErrorsMax", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "smi_link_corr_errors_min": MoPropertyMeta("smi_link_corr_errors_min", "smiLinkCorrErrorsMin", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "smi_link_corr_errors_running": MoPropertyMeta("smi_link_corr_errors_running", "smiLinkCorrErrorsRunning", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "smi_link_uncorr_errors": MoPropertyMeta("smi_link_uncorr_errors", "smiLinkUncorrErrors", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "smi_link_uncorr_errors_avg": MoPropertyMeta("smi_link_uncorr_errors_avg", "smiLinkUncorrErrorsAvg", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "smi_link_uncorr_errors_max": MoPropertyMeta("smi_link_uncorr_errors_max", "smiLinkUncorrErrorsMax", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "smi_link_uncorr_errors_min": MoPropertyMeta("smi_link_uncorr_errors_min", "smiLinkUncorrErrorsMin", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "smi_link_uncorr_errors_running": MoPropertyMeta("smi_link_uncorr_errors_running", "smiLinkUncorrErrorsRunning", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sparing_errors": MoPropertyMeta("sparing_errors", "sparingErrors", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sparing_errors_avg": MoPropertyMeta("sparing_errors_avg", "sparingErrorsAvg", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sparing_errors_max": MoPropertyMeta("sparing_errors_max", "sparingErrorsMax", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sparing_errors_min": MoPropertyMeta("sparing_errors_min", "sparingErrorsMin", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sparing_errors_running": MoPropertyMeta("sparing_errors_running", "sparingErrorsRunning", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "stats_reported": MoPropertyMeta("stats_reported", "statsReported", "int", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "mirroringInterSockErrors": "mirroring_inter_sock_errors", 
        "mirroringInterSockErrorsAvg": "mirroring_inter_sock_errors_avg", 
        "mirroringInterSockErrorsMax": "mirroring_inter_sock_errors_max", 
        "mirroringInterSockErrorsMin": "mirroring_inter_sock_errors_min", 
        "mirroringInterSockErrorsRunning": "mirroring_inter_sock_errors_running", 
        "mirroringIntraSockErrors": "mirroring_intra_sock_errors", 
        "mirroringIntraSockErrorsAvg": "mirroring_intra_sock_errors_avg", 
        "mirroringIntraSockErrorsMax": "mirroring_intra_sock_errors_max", 
        "mirroringIntraSockErrorsMin": "mirroring_intra_sock_errors_min", 
        "mirroringIntraSockErrorsRunning": "mirroring_intra_sock_errors_running", 
        "normalizedTimeCol": "normalized_time_col", 
        "rn": "rn", 
        "smiLinkCorrErrors": "smi_link_corr_errors", 
        "smiLinkCorrErrorsAvg": "smi_link_corr_errors_avg", 
        "smiLinkCorrErrorsMax": "smi_link_corr_errors_max", 
        "smiLinkCorrErrorsMin": "smi_link_corr_errors_min", 
        "smiLinkCorrErrorsRunning": "smi_link_corr_errors_running", 
        "smiLinkUncorrErrors": "smi_link_uncorr_errors", 
        "smiLinkUncorrErrorsAvg": "smi_link_uncorr_errors_avg", 
        "smiLinkUncorrErrorsMax": "smi_link_uncorr_errors_max", 
        "smiLinkUncorrErrorsMin": "smi_link_uncorr_errors_min", 
        "smiLinkUncorrErrorsRunning": "smi_link_uncorr_errors_running", 
        "sparingErrors": "sparing_errors", 
        "sparingErrorsAvg": "sparing_errors_avg", 
        "sparingErrorsMax": "sparing_errors_max", 
        "sparingErrorsMin": "sparing_errors_min", 
        "sparingErrorsRunning": "sparing_errors_running", 
        "statsReported": "stats_reported", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.intervals = None
        self.mirroring_inter_sock_errors = None
        self.mirroring_inter_sock_errors_avg = None
        self.mirroring_inter_sock_errors_max = None
        self.mirroring_inter_sock_errors_min = None
        self.mirroring_inter_sock_errors_running = None
        self.mirroring_intra_sock_errors = None
        self.mirroring_intra_sock_errors_avg = None
        self.mirroring_intra_sock_errors_max = None
        self.mirroring_intra_sock_errors_min = None
        self.mirroring_intra_sock_errors_running = None
        self.normalized_time_col = None
        self.smi_link_corr_errors = None
        self.smi_link_corr_errors_avg = None
        self.smi_link_corr_errors_max = None
        self.smi_link_corr_errors_min = None
        self.smi_link_corr_errors_running = None
        self.smi_link_uncorr_errors = None
        self.smi_link_uncorr_errors_avg = None
        self.smi_link_uncorr_errors_max = None
        self.smi_link_uncorr_errors_min = None
        self.smi_link_uncorr_errors_running = None
        self.sparing_errors = None
        self.sparing_errors_avg = None
        self.sparing_errors_max = None
        self.sparing_errors_min = None
        self.sparing_errors_running = None
        self.stats_reported = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "ProcessorErrorStats", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ComputeFactoryResetOperation ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ComputeFactoryResetOperationConsts():
    CREATE_INITIAL_VOLUMES_CREATE_INITIAL_VOLUMES = "create-initial-volumes"
    CREATE_INITIAL_VOLUMES_NO_INIT = "no-init"
    CREATE_INITIAL_VOLUMES_UNKNOWN = "unknown"
    FLEX_STORAGE_SCRUB_NO_SCRUB = "no-scrub"
    FLEX_STORAGE_SCRUB_SCRUB = "scrub"
    FLEX_STORAGE_SCRUB_UNKNOWN = "unknown"
    OPER_STATUS_CIMC_RESET_COMPLETE = "cimc-reset-complete"
    OPER_STATUS_CIMC_RESET_IN_PROGRESS = "cimc-reset-in-progress"
    OPER_STATUS_IDLE = "idle"
    OPER_STATUS_RUNNING = "running"
    OPER_STATUS_SCRUB_STAGE_COMPLETE = "scrub-stage-complete"
    RESET_TRIGGER_CANCELED = "canceled"
    RESET_TRIGGER_IDLE = "idle"
    RESET_TRIGGER_TRIGGERED = "triggered"
    STORAGE_SCRUB_NO_SCRUB = "no-scrub"
    STORAGE_SCRUB_SCRUB = "scrub"
    STORAGE_SCRUB_UNKNOWN = "unknown"


class ComputeFactoryResetOperation(ManagedObject):
    """This is ComputeFactoryResetOperation class."""

    consts = ComputeFactoryResetOperationConsts()
    naming_props = set([])

    mo_meta = MoMeta("ComputeFactoryResetOperation", "computeFactoryResetOperation", "factory-reset", VersionMeta.Version151a, "InputOutput", 0xff, [], ["admin", "pn-equipment", "pn-maintenance", "pn-policy"], [u'computeBlade', u'computeRackUnit', u'computeServerUnit'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "create_initial_volumes": MoPropertyMeta("create_initial_volumes", "createInitialVolumes", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["create-initial-volumes", "no-init", "unknown"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "flex_storage_scrub": MoPropertyMeta("flex_storage_scrub", "flexStorageScrub", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["no-scrub", "scrub", "unknown"], []), 
        "oper_status": MoPropertyMeta("oper_status", "operStatus", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["cimc-reset-complete", "cimc-reset-in-progress", "idle", "running", "scrub-stage-complete"], []), 
        "reset_trigger": MoPropertyMeta("reset_trigger", "resetTrigger", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["canceled", "idle", "triggered"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "storage_scrub": MoPropertyMeta("storage_scrub", "storageScrub", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["no-scrub", "scrub", "unknown"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "createInitialVolumes": "create_initial_volumes", 
        "dn": "dn", 
        "flexStorageScrub": "flex_storage_scrub", 
        "operStatus": "oper_status", 
        "resetTrigger": "reset_trigger", 
        "rn": "rn", 
        "status": "status", 
        "storageScrub": "storage_scrub", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.create_initial_volumes = None
        self.flex_storage_scrub = None
        self.oper_status = None
        self.reset_trigger = None
        self.status = None
        self.storage_scrub = None

        ManagedObject.__init__(self, "ComputeFactoryResetOperation", parent_mo_or_dn, **kwargs)




"""This module contains the general information for LsSPMeta ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class LsSPMetaConsts():
    GLOBALIZATION_STATE_GLOBALIZED = "Globalized"
    GLOBALIZATION_STATE_GLOBALIZING = "globalizing"
    GLOBALIZATION_STATE_NO_OP = "no-op"
    IS_RENAME_FALSE = "false"
    IS_RENAME_NO = "no"
    IS_RENAME_TRUE = "true"
    IS_RENAME_YES = "yes"
    NEED_ID_RE_EVALUATE_NO = "no"
    NEED_ID_RE_EVALUATE_YES = "yes"
    OPERATION_CODE_ASSOCIATE = "associate"
    OPERATION_CODE_DELETION = "deletion"
    OPERATION_CODE_DISASSOCIATE = "disassociate"
    OPERATION_CODE_GLOBALIZATION = "globalization"
    OPERATION_CODE_NO_OP = "no-op"
    OPERATION_CODE_RENAME = "rename"
    OPERATION_CODE_CLEARANCE_DISABLED = "disabled"
    OPERATION_CODE_CLEARANCE_ENABLED = "enabled"
    OWNERSHIP_STATE_DELETE_PENDING = "delete-pending"
    OWNERSHIP_STATE_DISASSOC_PENDING = "disassoc-pending"
    OWNERSHIP_STATE_GLOBAL_CONTROLLED = "global-controlled"
    OWNERSHIP_STATE_LOCALIZED = "localized"
    SP_REFRESH_DISABLED = "disabled"
    SP_REFRESH_ENABLED = "enabled"


class LsSPMeta(ManagedObject):
    """This is LsSPMeta class."""

    consts = LsSPMetaConsts()
    naming_props = set([])

    mo_meta = MoMeta("LsSPMeta", "lsSPMeta", "spmeta", VersionMeta.Version111a, "InputOutput", 0x7f, [], ["admin", "ls-compute", "ls-config", "ls-server", "ls-server-oper", "ls-server-policy"], [u'lsServer'], [u'faultInst', u'messageEntry', u'messageEp'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "config_qualifier": MoPropertyMeta("config_qualifier", "configQualifier", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|not-applicable|ungrouped-domain),){0,2}(defaultValue|not-applicable|ungrouped-domain){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "globalization_state": MoPropertyMeta("globalization_state", "globalizationState", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["Globalized", "globalizing", "no-op"], []), 
        "guid": MoPropertyMeta("guid", "guid", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "is_rename": MoPropertyMeta("is_rename", "isRename", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "need_id_re_evaluate": MoPropertyMeta("need_id_re_evaluate", "needIdReEvaluate", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []), 
        "new_spdn": MoPropertyMeta("new_spdn", "newSPDN", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "old_spdn": MoPropertyMeta("old_spdn", "oldSPDN", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "operation_code": MoPropertyMeta("operation_code", "operationCode", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["associate", "deletion", "disassociate", "globalization", "no-op", "rename"], []), 
        "operation_code_clearance": MoPropertyMeta("operation_code_clearance", "operationCodeClearance", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["disabled", "enabled"], []), 
        "ownership_state": MoPropertyMeta("ownership_state", "ownershipState", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["delete-pending", "disassoc-pending", "global-controlled", "localized"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "server_dn": MoPropertyMeta("server_dn", "serverDn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "sp_refresh": MoPropertyMeta("sp_refresh", "spRefresh", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["disabled", "enabled"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "configQualifier": "config_qualifier", 
        "dn": "dn", 
        "globalizationState": "globalization_state", 
        "guid": "guid", 
        "isRename": "is_rename", 
        "needIdReEvaluate": "need_id_re_evaluate", 
        "newSPDN": "new_spdn", 
        "oldSPDN": "old_spdn", 
        "operationCode": "operation_code", 
        "operationCodeClearance": "operation_code_clearance", 
        "ownershipState": "ownership_state", 
        "rn": "rn", 
        "serverDn": "server_dn", 
        "spRefresh": "sp_refresh", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.config_qualifier = None
        self.globalization_state = None
        self.guid = None
        self.is_rename = None
        self.need_id_re_evaluate = None
        self.new_spdn = None
        self.old_spdn = None
        self.operation_code = None
        self.operation_code_clearance = None
        self.ownership_state = None
        self.server_dn = None
        self.sp_refresh = None
        self.status = None

        ManagedObject.__init__(self, "LsSPMeta", parent_mo_or_dn, **kwargs)




"""This module contains the general information for StorageItem ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StorageItemConsts():
    HIGH_SPEED_NOT_APPLICABLE = "not-applicable"
    LOW_SPEED_NOT_APPLICABLE = "not-applicable"
    NORMAL_SPEED_NOT_APPLICABLE = "not-applicable"
    READ_SPEED_NOT_APPLICABLE = "not-applicable"
    SIZE_NOTHING = "nothing"
    USED_EMPTY = "empty"
    USED_FULL = "full"
    USED_NOT_APPLICABLE = "not-applicable"


class StorageItem(ManagedObject):
    """This is StorageItem class."""

    consts = StorageItemConsts()
    naming_props = set([u'name'])

    mo_meta = MoMeta("StorageItem", "storageItem", "stor-part-[name]", VersionMeta.Version101a, "InputOutput", 0x3f, [], ["read-only"], [u'networkElement', u'nfsExportDef'], [u'faultInst'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "high_speed": MoPropertyMeta("high_speed", "highSpeed", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "low_speed": MoPropertyMeta("low_speed", "lowSpeed", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x4, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []), 
        "normal_speed": MoPropertyMeta("normal_speed", "normalSpeed", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "read_speed": MoPropertyMeta("read_speed", "readSpeed", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "size": MoPropertyMeta("size", "size", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["nothing"], ["0-4294967295"]), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "system_name": MoPropertyMeta("system_name", "systemName", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "used": MoPropertyMeta("used", "used", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["empty", "full", "not-applicable"], ["0-101"]), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "highSpeed": "high_speed", 
        "lowSpeed": "low_speed", 
        "name": "name", 
        "normalSpeed": "normal_speed", 
        "readSpeed": "read_speed", 
        "rn": "rn", 
        "size": "size", 
        "status": "status", 
        "systemName": "system_name", 
        "used": "used", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.high_speed = None
        self.low_speed = None
        self.normal_speed = None
        self.read_speed = None
        self.size = None
        self.status = None
        self.system_name = None
        self.used = None

        ManagedObject.__init__(self, "StorageItem", parent_mo_or_dn, **kwargs)




"""This module contains the meta information of FirmwareEstimatePackImpact ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("FirmwareEstimatePackImpact", "firmwareEstimatePackImpact", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "dn": MethodPropertyMeta("Dn", "dn", "ReferenceObject", "Version142b", "InputOutput", False),
    "in_group_dn": MethodPropertyMeta("InGroupDn", "inGroupDn", "ReferenceObject", "Version142b", "Input", False),
    "in_pack_configs": MethodPropertyMeta("InPackConfigs", "inPackConfigs", "ConfigSet", "Version142b", "Input", True),
    "out_config_set": MethodPropertyMeta("OutConfigSet", "outConfigSet", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "dn": "dn",
    "inGroupDn": "in_group_dn",
    "inPackConfigs": "in_pack_configs",
    "outConfigSet": "out_config_set",
}




"""This module contains the general information for FirmwareBootUnit ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FirmwareBootUnitConsts():
    ADMIN_STATE_FORCE_TRIGGER = "force-trigger"
    ADMIN_STATE_TRIGGER = "trigger"
    ADMIN_STATE_TRIGGERED = "triggered"
    IGNORE_COMP_CHECK_FALSE = "false"
    IGNORE_COMP_CHECK_NO = "no"
    IGNORE_COMP_CHECK_TRUE = "true"
    IGNORE_COMP_CHECK_YES = "yes"
    OPER_STATE_ACTIVATING = "activating"
    OPER_STATE_BAD_IMAGE = "bad-image"
    OPER_STATE_FAILED = "failed"
    OPER_STATE_PENDING_NEXT_BOOT = "pending-next-boot"
    OPER_STATE_READY = "ready"
    OPER_STATE_REBOOTING = "rebooting"
    OPER_STATE_SCHEDULED = "scheduled"
    OPER_STATE_SET_STARTUP = "set-startup"
    OPER_STATE_THROTTLED = "throttled"
    OPER_STATE_UPDATING = "updating"
    OPER_STATE_UPGRADING = "upgrading"
    RESET_ON_ACTIVATE_FALSE = "false"
    RESET_ON_ACTIVATE_NO = "no"
    RESET_ON_ACTIVATE_TRUE = "true"
    RESET_ON_ACTIVATE_YES = "yes"
    SKIP_VALIDATION_FALSE = "false"
    SKIP_VALIDATION_NO = "no"
    SKIP_VALIDATION_TRUE = "true"
    SKIP_VALIDATION_YES = "yes"


class FirmwareBootUnit(ManagedObject):
    """This is FirmwareBootUnit class."""

    consts = FirmwareBootUnitConsts()
    naming_props = set([u'type'])

    mo_meta = MoMeta("FirmwareBootUnit", "firmwareBootUnit", "bootunit-[type]", VersionMeta.Version101a, "InputOutput", 0x7ff, [], ["admin"], [u'firmwareBootDefinition'], [], ["Get", "Set"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["force-trigger", "trigger", "triggered"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "ignore_comp_check": MoPropertyMeta("ignore_comp_check", "ignoreCompCheck", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["false", "no", "true", "yes"], []), 
        "image": MoPropertyMeta("image", "image", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "inv_tag": MoPropertyMeta("inv_tag", "invTag", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "mode": MoPropertyMeta("mode", "mode", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, [], []), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["activating", "bad-image", "failed", "pending-next-boot", "ready", "rebooting", "scheduled", "set-startup", "throttled", "updating", "upgrading"], []), 
        "prev_version": MoPropertyMeta("prev_version", "prevVersion", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "reset_on_activate": MoPropertyMeta("reset_on_activate", "resetOnActivate", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["false", "no", "true", "yes"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []), 
        "skip_validation": MoPropertyMeta("skip_validation", "skipValidation", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["false", "no", "true", "yes"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x200, None, None, r"""((kernel|system|combined|boot-loader|service-pack),){0,4}(kernel|system|combined|boot-loader|service-pack){0,1}""", [], []), 
        "version": MoPropertyMeta("version", "version", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x400, 0, 510, None, [], []), 
    }

    prop_map = {
        "adminState": "admin_state", 
        "childAction": "child_action", 
        "dn": "dn", 
        "ignoreCompCheck": "ignore_comp_check", 
        "image": "image", 
        "invTag": "inv_tag", 
        "mode": "mode", 
        "operState": "oper_state", 
        "prevVersion": "prev_version", 
        "resetOnActivate": "reset_on_activate", 
        "rn": "rn", 
        "skipValidation": "skip_validation", 
        "status": "status", 
        "type": "type", 
        "version": "version", 
    }

    def __init__(self, parent_mo_or_dn, type, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.admin_state = None
        self.child_action = None
        self.ignore_comp_check = None
        self.image = None
        self.inv_tag = None
        self.mode = None
        self.oper_state = None
        self.prev_version = None
        self.reset_on_activate = None
        self.skip_validation = None
        self.status = None
        self.version = None

        ManagedObject.__init__(self, "FirmwareBootUnit", parent_mo_or_dn, **kwargs)




"""This module contains the general information for StorageOperation ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StorageOperationConsts():
    END_TIME_N_A = "N/A"
    NAME_CONSISTENCY_CHECK = "consistency-check"
    NAME_COPYBACK = "copyback"
    NAME_INITIALIZATION = "initialization"
    NAME_PATROL_READ = "patrol-read"
    NAME_REBUILD = "rebuild"
    NAME_RECONSTRUCTION = "reconstruction"
    NAME_RELEARNING = "relearning"
    OPER_STATE_COMPLETED = "completed"
    OPER_STATE_FAILED = "failed"
    OPER_STATE_IN_PROGRESS = "in-progress"
    OPER_STATE_UNKNOWN = "unknown"
    PROGRESS_NOT_APPLICABLE = "not-applicable"
    PROGRESS_UNKNOWN = "unknown"
    START_TIME_N_A = "N/A"


class StorageOperation(ManagedObject):
    """This is StorageOperation class."""

    consts = StorageOperationConsts()
    naming_props = set([u'name'])

    mo_meta = MoMeta("StorageOperation", "storageOperation", "op-[name]", VersionMeta.Version131a, "InputOutput", 0x1f, [], ["read-only"], [u'storageController', u'storageLocalDisk', u'storageRaidBattery', u'storageVirtualDrive'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "end_time": MoPropertyMeta("end_time", "endTime", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["N/A"], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version131a, MoPropertyMeta.NAMING, 0x4, None, None, None, ["consistency-check", "copyback", "initialization", "patrol-read", "rebuild", "reconstruction", "relearning"], []), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["completed", "failed", "in-progress", "unknown"], []), 
        "progress": MoPropertyMeta("progress", "progress", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable", "unknown"], ["0-101"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "start_time": MoPropertyMeta("start_time", "startTime", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["N/A"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "status_descr": MoPropertyMeta("status_descr", "statusDescr", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "endTime": "end_time", 
        "name": "name", 
        "operState": "oper_state", 
        "progress": "progress", 
        "rn": "rn", 
        "startTime": "start_time", 
        "status": "status", 
        "statusDescr": "status_descr", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.end_time = None
        self.oper_state = None
        self.progress = None
        self.start_time = None
        self.status = None
        self.status_descr = None

        ManagedObject.__init__(self, "StorageOperation", parent_mo_or_dn, **kwargs)




"""This module contains the meta information of ConfigGetQualifiedDomains ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigGetQualifiedDomains", "configGetQualifiedDomains", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_qual_dn": MethodPropertyMeta("InQualDn", "inQualDn", "ReferenceObject", "Version142b", "Input", False),
    "in_return_domain_configs": MethodPropertyMeta("InReturnDomainConfigs", "inReturnDomainConfigs", "Xs:string", "Version142b", "Input", False),
    "in_return_policy_configs": MethodPropertyMeta("InReturnPolicyConfigs", "inReturnPolicyConfigs", "Xs:string", "Version142b", "Input", False),
    "out_domains": MethodPropertyMeta("OutDomains", "outDomains", "ConfigSet", "Version142b", "Output", True),
    "out_policies": MethodPropertyMeta("OutPolicies", "outPolicies", "ConfigSet", "Version142b", "Output", True),
    "out_total_domains": MethodPropertyMeta("OutTotalDomains", "outTotalDomains", "Xs:unsignedInt", "Version142b", "Output", False),
    "out_total_policies": MethodPropertyMeta("OutTotalPolicies", "outTotalPolicies", "Xs:unsignedInt", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "inQualDn": "in_qual_dn",
    "inReturnDomainConfigs": "in_return_domain_configs",
    "inReturnPolicyConfigs": "in_return_policy_configs",
    "outDomains": "out_domains",
    "outPolicies": "out_policies",
    "outTotalDomains": "out_total_domains",
    "outTotalPolicies": "out_total_policies",
}




"""This module contains the general information for FcStats ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FcStatsConsts():
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class FcStats(ManagedObject):
    """This is FcStats class."""

    consts = FcStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("FcStats", "fcStats", "stats", VersionMeta.Version111a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], [], [u'fcStatsHist'], [None])

    prop_meta = {
        "bytes_rx": MoPropertyMeta("bytes_rx", "bytesRx", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "bytes_rx_delta": MoPropertyMeta("bytes_rx_delta", "bytesRxDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "bytes_rx_delta_avg": MoPropertyMeta("bytes_rx_delta_avg", "bytesRxDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "bytes_rx_delta_max": MoPropertyMeta("bytes_rx_delta_max", "bytesRxDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "bytes_rx_delta_min": MoPropertyMeta("bytes_rx_delta_min", "bytesRxDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "bytes_tx": MoPropertyMeta("bytes_tx", "bytesTx", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "bytes_tx_delta": MoPropertyMeta("bytes_tx_delta", "bytesTxDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "bytes_tx_delta_avg": MoPropertyMeta("bytes_tx_delta_avg", "bytesTxDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "bytes_tx_delta_max": MoPropertyMeta("bytes_tx_delta_max", "bytesTxDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "bytes_tx_delta_min": MoPropertyMeta("bytes_tx_delta_min", "bytesTxDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "normalized_time_col": MoPropertyMeta("normalized_time_col", "normalizedTimeCol", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "packets_rx": MoPropertyMeta("packets_rx", "packetsRx", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "packets_rx_delta": MoPropertyMeta("packets_rx_delta", "packetsRxDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "packets_rx_delta_avg": MoPropertyMeta("packets_rx_delta_avg", "packetsRxDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "packets_rx_delta_max": MoPropertyMeta("packets_rx_delta_max", "packetsRxDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "packets_rx_delta_min": MoPropertyMeta("packets_rx_delta_min", "packetsRxDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "packets_tx": MoPropertyMeta("packets_tx", "packetsTx", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "packets_tx_delta": MoPropertyMeta("packets_tx_delta", "packetsTxDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "packets_tx_delta_avg": MoPropertyMeta("packets_tx_delta_avg", "packetsTxDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "packets_tx_delta_max": MoPropertyMeta("packets_tx_delta_max", "packetsTxDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "packets_tx_delta_min": MoPropertyMeta("packets_tx_delta_min", "packetsTxDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "stats_reported": MoPropertyMeta("stats_reported", "statsReported", "int", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "bytesRx": "bytes_rx", 
        "bytesRxDelta": "bytes_rx_delta", 
        "bytesRxDeltaAvg": "bytes_rx_delta_avg", 
        "bytesRxDeltaMax": "bytes_rx_delta_max", 
        "bytesRxDeltaMin": "bytes_rx_delta_min", 
        "bytesTx": "bytes_tx", 
        "bytesTxDelta": "bytes_tx_delta", 
        "bytesTxDeltaAvg": "bytes_tx_delta_avg", 
        "bytesTxDeltaMax": "bytes_tx_delta_max", 
        "bytesTxDeltaMin": "bytes_tx_delta_min", 
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "normalizedTimeCol": "normalized_time_col", 
        "packetsRx": "packets_rx", 
        "packetsRxDelta": "packets_rx_delta", 
        "packetsRxDeltaAvg": "packets_rx_delta_avg", 
        "packetsRxDeltaMax": "packets_rx_delta_max", 
        "packetsRxDeltaMin": "packets_rx_delta_min", 
        "packetsTx": "packets_tx", 
        "packetsTxDelta": "packets_tx_delta", 
        "packetsTxDeltaAvg": "packets_tx_delta_avg", 
        "packetsTxDeltaMax": "packets_tx_delta_max", 
        "packetsTxDeltaMin": "packets_tx_delta_min", 
        "rn": "rn", 
        "statsReported": "stats_reported", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.bytes_rx = None
        self.bytes_rx_delta = None
        self.bytes_rx_delta_avg = None
        self.bytes_rx_delta_max = None
        self.bytes_rx_delta_min = None
        self.bytes_tx = None
        self.bytes_tx_delta = None
        self.bytes_tx_delta_avg = None
        self.bytes_tx_delta_max = None
        self.bytes_tx_delta_min = None
        self.child_action = None
        self.intervals = None
        self.normalized_time_col = None
        self.packets_rx = None
        self.packets_rx_delta = None
        self.packets_rx_delta_avg = None
        self.packets_rx_delta_max = None
        self.packets_rx_delta_min = None
        self.packets_tx = None
        self.packets_tx_delta = None
        self.packets_tx_delta_avg = None
        self.packets_tx_delta_max = None
        self.packets_tx_delta_min = None
        self.stats_reported = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "FcStats", parent_mo_or_dn, **kwargs)




"""This module contains the general information for FabricVlanPermitItem ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FabricVlanPermitItemConsts():
    SHARING_COMMUNITY = "community"
    SHARING_ISOLATED = "isolated"
    SHARING_NONE = "none"
    SHARING_PRIMARY = "primary"
    VLAN_STATUS_ASSIGNED = "assigned"
    VLAN_STATUS_AVAILABLE = "available"
    VLAN_STATUS_IN_USE = "in-use"
    VLAN_SWITCH_ID_A = "A"
    VLAN_SWITCH_ID_B = "B"
    VLAN_SWITCH_ID_NONE = "NONE"
    VLAN_SWITCH_ID_MGMT = "mgmt"


class FabricVlanPermitItem(ManagedObject):
    """This is FabricVlanPermitItem class."""

    consts = FabricVlanPermitItemConsts()
    naming_props = set([u'vlanName'])

    mo_meta = MoMeta("FabricVlanPermitItem", "fabricVlanPermitItem", "vlan-permit-item-[vlan_name]", VersionMeta.Version141a, "InputOutput", 0x1f, [], ["read-only"], [], [u'configOrgItem'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "domain_group_dn": MoPropertyMeta("domain_group_dn", "domainGroupDn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "domain_group_name": MoPropertyMeta("domain_group_name", "domainGroupName", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "pub_nw_name": MoPropertyMeta("pub_nw_name", "pubNwName", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "sharing": MoPropertyMeta("sharing", "sharing", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["community", "isolated", "none", "primary"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "vlan_dn": MoPropertyMeta("vlan_dn", "vlanDn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "vlan_id": MoPropertyMeta("vlan_id", "vlanId", "uint", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["1-4093"]), 
        "vlan_name": MoPropertyMeta("vlan_name", "vlanName", "string", VersionMeta.Version141a, MoPropertyMeta.NAMING, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []), 
        "vlan_status": MoPropertyMeta("vlan_status", "vlanStatus", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["assigned", "available", "in-use"], []), 
        "vlan_switch_id": MoPropertyMeta("vlan_switch_id", "vlanSwitchId", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["A", "B", "NONE", "mgmt"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "domainGroupDn": "domain_group_dn", 
        "domainGroupName": "domain_group_name", 
        "pubNwName": "pub_nw_name", 
        "rn": "rn", 
        "sharing": "sharing", 
        "status": "status", 
        "vlanDn": "vlan_dn", 
        "vlanId": "vlan_id", 
        "vlanName": "vlan_name", 
        "vlanStatus": "vlan_status", 
        "vlanSwitchId": "vlan_switch_id", 
    }

    def __init__(self, parent_mo_or_dn, vlan_name, **kwargs):
        self._dirty_mask = 0
        self.vlan_name = vlan_name
        self.child_action = None
        self.domain_group_dn = None
        self.domain_group_name = None
        self.pub_nw_name = None
        self.sharing = None
        self.status = None
        self.vlan_dn = None
        self.vlan_id = None
        self.vlan_status = None
        self.vlan_switch_id = None

        ManagedObject.__init__(self, "FabricVlanPermitItem", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigDbConfig ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigDbConfigConsts():
    DB_ERROR_FALSE = "false"
    DB_ERROR_NO = "no"
    DB_ERROR_TRUE = "true"
    DB_ERROR_YES = "yes"
    TYPE_MSSQL = "mssql"
    TYPE_ORACLE = "oracle"
    TYPE_POSTGRES = "postgres"
    TYPE_UNKNOWN = "unknown"


class ConfigDbConfig(ManagedObject):
    """This is ConfigDbConfig class."""

    consts = ConfigDbConfigConsts()
    naming_props = set([])

    mo_meta = MoMeta("ConfigDbConfig", "configDbConfig", "dbconfig", VersionMeta.Version111b, "InputOutput", 0x7ff, [], ["admin"], [u'topSystem'], [u'faultInst'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111b, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "database": MoPropertyMeta("database", "database", "string", VersionMeta.Version111b, MoPropertyMeta.READ_WRITE, 0x2, 0, 510, None, [], []), 
        "db_error": MoPropertyMeta("db_error", "dbError", "string", VersionMeta.Version111b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "hostname": MoPropertyMeta("hostname", "hostname", "string", VersionMeta.Version111b, MoPropertyMeta.READ_WRITE, 0x8, 1, 255, None, [], []), 
        "instance": MoPropertyMeta("instance", "instance", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, 0, 32, None, [], []), 
        "last_db_status": MoPropertyMeta("last_db_status", "lastDbStatus", "string", VersionMeta.Version111b, MoPropertyMeta.READ_ONLY, None, 0, 999, None, [], []), 
        "port": MoPropertyMeta("port", "port", "ushort", VersionMeta.Version111b, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], []), 
        "pwd": MoPropertyMeta("pwd", "pwd", "string", VersionMeta.Version111b, MoPropertyMeta.READ_WRITE, 0x40, 0, 64, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111b, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111b, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version111b, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["mssql", "oracle", "postgres", "unknown"], []), 
        "user": MoPropertyMeta("user", "user", "string", VersionMeta.Version111b, MoPropertyMeta.READ_WRITE, 0x400, 0, 510, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "database": "database", 
        "dbError": "db_error", 
        "dn": "dn", 
        "hostname": "hostname", 
        "instance": "instance", 
        "lastDbStatus": "last_db_status", 
        "port": "port", 
        "pwd": "pwd", 
        "rn": "rn", 
        "status": "status", 
        "type": "type", 
        "user": "user", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.database = None
        self.db_error = None
        self.hostname = None
        self.instance = None
        self.last_db_status = None
        self.port = None
        self.pwd = None
        self.status = None
        self.type = None
        self.user = None

        ManagedObject.__init__(self, "ConfigDbConfig", parent_mo_or_dn, **kwargs)

